#!/bin/bash
echo -e "\e[1;5m\n== Initial SciViews Box 2019 setup…\e[0m"

# TODO:
# - Install stackedit locally (and may be hack to edit .Rmd files too?)
#   git clone https://github.com/benweet/stackedit
#   cd stackedit
#   npm install
#   To access StackEdit, open your browser to localhost:3000

# We try to avoid asking for password by using the default one with sudo
# If it fails, ask anyway!
#echo 'sv\n' | sudo -S ls > /dev/null 2> /dev/null
# Ask password with a GUI (because Windows or Mac users are surprised with the
# default terminal interface where typed characters are not echoed with stars!)
mkdir -p /home/sv/.config/svbox
echo '#!/bin/bash
yad --on-top --title "sudo password prompt" \
  --text="<b>Enter your password</b>\n\nThe installer needs it for administrative tasks.\n\n" \
  --window-icon=dialog-password --image=dialog-password --borders=6 --center --fixed \
  --entry --hide-text 2> /dev/null
' > /home/sv/.config/svbox/askpass
chmod +x /home/sv/.config/svbox/askpass
export SUDO_ASKPASS="/home/sv/.config/svbox/askpass"
sudo -A ls > /dev/null

# Warn the user
notify-send "SciViews Box Configuration v. 1" "Please wait: configuration in course... the machine will reboot when done."

# Make sure there is no unattended update in course
pkill -f update-notifier
pkill -f update-manager
sudo systemctl stop apt-daily.service apt-daily.timer apt-daily-upgrade.service apt-daily-upgrade.timer
sudo systemctl kill --kill-who=all apt-daily.service apt-daily-upgrade.service
if ! (systemctl list-units --all apt-daily.service | grep -q failed); then
  while ! (systemctl list-units --all apt-daily.service | grep -q dead); do sleep 1; done;
fi
if ! (systemctl list-units --all apt-daily-upgrade.service | grep -q failed); then
  while ! (systemctl list-units --all apt-daily-upgrade.service | grep -q dead); do sleep 1; done;
fi
sudo rm /var/lib/apt/lists/lock
sudo rm /var/cache/apt/archives/lock
sudo rm /var/lib/dpkg/lock
sudo dpkg --configure -a
# Disable unattended upgrade
sudo sed -i 's/APT::Periodic::Update-Package-Lists "1"/APT::Periodic::Update-Package-Lists "0"/' /etc/apt/apt.conf.d/20auto-upgrades
sudo sed -i 's/APT::Periodic::Unattended-Upgrade "1"/APT::Periodic::Unattended-Upgrade "0"/' /etc/apt/apt.conf.d/20auto-upgrades


echo "Populate the shared folder..."
cp -nr shared/* /media/sf_shared
# Or for a compressed version using tar -cvJf shared.tar.xz --exclude .DS_Store shared
#cp shared.tar.xz /media
#tar -xvJf shared.tar.xz
#rm shared.tar.xz


echo "Install more applications..."
# biter, a much better bibtex used by vitae R package
sudo apt install -y biber
# Useful for the gganimate package
sudo snap install gifski
# To install the gifski R package one needs Rust, which takes 320Mb more, so,
# we prefer to use the magick_renbderer() for gganiumate::animate() by default
echo '
options(gganimate.renderer = gganimate::magick_renderer())
' | sudo tee -a $(R RHOME)/etc/Rprofile.site > /dev/null


echo "Update R packages..."
# Make sure that the faraway R package is installed
sudo -i R -q -e 'install.packages("faraway", lib = "/usr/local/lib/R/site-library", dependencies = TRUE)'
# Update the R snippets
# TODO: check version first and update only inside the SciViews R section!
#cp -f r.snippets ~/.R/snippets/r.snippets
# Update data.io and chart
#sudo -i R -q -e '.libPaths("/usr/local/lib/R/site-library"); if (packageVersion("data.io") < "1.2") devtools::install_github("SciViews/flow@v1.0")'


# Record the version of the SciViews Box in /etc/svbox
svbox="SciViews Box 2019 v1.0"
echo "$svbox" | sudo tee /etc/svbox > /dev/null
# ...and more infos in /etc/svboxinfo

# Since there may be an old svautoinstall script, make sure this app is recorded
# and svBox information is updated
mkdir -p /home/sv/.config/svbox
svboxapp="svbox2019 v1.0.0"
if [ "$(tail -n 1 -q /home/sv/.config/svbox/installed-apps 2> /dev/null)" != "$svboxapp" ]; then \
  echo "$svboxapp" >> /home/sv/.config/svbox/installed-apps; fi
svinforefresh

echo "Clean up the system..."
sudo apt autoremove -y
sudo apt autoclean -y
sudo apt clean -y

# Proceed with manual configuration now
svconfig --noreboot

# Now, we need to reboot the computer
yad --title="SciViews Box Configuration v. 3" \
    --text="The machine needs to reboot to complete the configuration... (waiting 30 sec)" \
    --window-icon="/home/sv/.icons/svBox-512.png" \
    --image="/home/sv/.icons/svBox-64.png" --on-top \
    --sticky --center --borders=6 \
    --timeout=30 --timeout-indicator=bottom \
      2>/dev/null
ret=$?

[[ $ret -eq 0 ]] && sudo reboot
[[ $ret -eq 70 ]] && sudo reboot
