kmeans_cluster <- function(dataset) {

  library(shiny)

  shiny.input <<- list(xcol = "Sepal.Length", ycol = "Petal.Length", clusters = 3)

  print(shinyApp(
    ui = fluidPage(
      fluidRow(style = "padding-bottom: 20px;",
        column(4, selectInput("xcol", "X Variable", names(dataset))),
        column(4, selectInput("ycol", "Y Variable", names(dataset),
          selected = names(dataset)[[2]])),
        column(4, numericInput("clusters", "Cluster count", 3, min = 1, max = 9))
      ),
      fluidRow(plotOutput("kmeans", height = "400px"))
    ),

    server = function(input, output, session) {
      selectedData <- reactive({
        shiny.input$xcol <<- input$xcol
        shiny.input$ycol <<- input$ycol
        dataset[, c(input$xcol, input$ycol)]
      })
      clusters <- reactive({
        shiny.input$clusters <<- input$clusters
        kmeans(selectedData(), input$clusters)
      })
      output$kmeans <- renderPlot(height = 400, {
        par(mar = c(5.1, 4.1, 0, 1))
        plot(selectedData(), col = clusters()$cluster, pch = 20, cex = 3)
        points(clusters()$centers, pch = 4, cex = 4, lwd = 4)
      })
    },

    options = list(height = 500)
  ))

  shiny.input
}
kmeans_cluster(iris)
